import { HttpModule } from '@nestjs/axios';
import { HttpStatus } from '@nestjs/common';
import { Test } from '@nestjs/testing';
import { MailerModule } from '../mailer/mailer.module';
import { TempUserController } from './temp-user.controller';
import { TempUserService } from './temp-user.service';

describe('TempUserService', () => {
  let tempUserController: TempUserController;

  const mockTempUserService = {
    findById: jest.fn(),
    findAll: jest.fn(),
  };

  beforeEach(async () => {
    const module = await Test.createTestingModule({
      imports: [HttpModule, MailerModule],
      providers: [{ provide: TempUserService, useValue: mockTempUserService }],
      controllers: [TempUserController],
    }).compile();

    tempUserController = module.get<TempUserController>(TempUserController);
  });

  it('should be defined', () => {
    expect(tempUserController).toBeDefined();
  });

  describe('getTempUser', () => {
    it('should get a temporary user by ID', async () => {
      const tmpUser = { email: 'test@test.com', structuresLink: [] };
      mockTempUserService.findById.mockReturnValueOnce(tmpUser);
      expect(await tempUserController.getTempUser('addq651')).toEqual(tmpUser);
    });
    it('should get all temporary users', async () => {
      const tempUsers = [
        { email: 'test@test.com', structuresLink: [] },
        { email: 'test2@test.com', structuresLink: [] },
      ];
      mockTempUserService.findAll.mockReturnValueOnce(tempUsers);
      const findAllTempUsers = await tempUserController.findAll();
      expect(findAllTempUsers.length).toBe(2);
    });
    it('should throw error in case of no users', async () => {
      const tmpUser = null;
      mockTempUserService.findById.mockReturnValueOnce(tmpUser);
      try {
        await tempUserController.getTempUser('addq651');
        expect(true).toBe(false);
      } catch (e) {
        expect(e.message).toEqual('Temp user does not exist');
        expect(e.status).toEqual(HttpStatus.BAD_REQUEST);
      }
    });
  });
});
