import { Controller, Get, HttpException, HttpStatus, Param } from '@nestjs/common';
import { ApiParam } from '@nestjs/swagger';
import { TempUser } from './temp-user.schema';
import { TempUserService } from './temp-user.service';

@Controller('temp-user')
export class TempUserController {
  constructor(private readonly tempUserService: TempUserService) {}

  @Get()
  public async findAll(): Promise<TempUser[]> {
    try {
      const tempUsers: TempUser[] = await this.tempUserService.findAll();
      return tempUsers;
    } catch (error) {
      throw new HttpException('An error occurred while fetching temp users.', HttpStatus.INTERNAL_SERVER_ERROR);
    }
  }

  @Get(':id')
  @ApiParam({ name: 'id', type: String, required: true })
  public async getTempUser(@Param('id') id: string): Promise<TempUser> {
    const user = await this.tempUserService.findById(id);
    if (!user) {
      throw new HttpException('Temp user does not exist', HttpStatus.BAD_REQUEST);
    }
    return user;
  }
}
